"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RouteTransferRequest = void 0;
const sdk_base_1 = require("@wormhole-foundation/sdk-base");
const token_1 = require("./token");
class RouteTransferRequest {
    from;
    to;
    source;
    destination;
    fromChain;
    toChain;
    constructor(from, to, fromChain, toChain, source, destination) {
        this.from = from;
        this.fromChain = fromChain;
        this.to = to;
        this.toChain = toChain;
        this.source = source;
        this.destination = destination;
    }
    parseAmount(amt) {
        return sdk_base_1.amount.parse(amt, this.source.decimals);
    }
    amountFromBaseUnits(amt) {
        return sdk_base_1.amount.fromBaseUnits(amt, this.source.decimals);
    }
    async displayQuote(quote) {
        // If we have a destination native gas
        // since the dest token is `native` on the dest chain
        const dstDecimals = quote.destinationNativeGas
            ? await this.toChain.getDecimals(quote.destinationToken.token.address)
            : this.destination.decimals;
        let dq = {
            sourceToken: {
                token: quote.sourceToken.token,
                amount: sdk_base_1.amount.fromBaseUnits(quote.sourceToken.amount, this.source.decimals),
            },
            destinationToken: {
                token: quote.destinationToken.token,
                amount: sdk_base_1.amount.fromBaseUnits(quote.destinationToken.amount, dstDecimals),
            },
        };
        if (quote.relayFee) {
            dq.relayFee = {
                token: quote.relayFee.token,
                amount: sdk_base_1.amount.fromBaseUnits(quote.relayFee.amount, this.source.decimals),
            };
        }
        if (quote.destinationNativeGas) {
            dq.destinationNativeGas = sdk_base_1.amount.fromBaseUnits(quote.destinationNativeGas, this.destination.decimals);
        }
        return dq;
    }
    static async create(wh, params, fromChain, toChain) {
        fromChain = fromChain ?? wh.getChain(params.from.chain);
        toChain = toChain ?? wh.getChain(params.to.chain);
        const sourceDetails = await (0, token_1.getTokenDetails)(fromChain, params.source);
        const destDetails = await (0, token_1.getTokenDetails)(toChain, params.destination);
        const rtr = new RouteTransferRequest(params.from, params.to, fromChain, toChain, sourceDetails, destDetails);
        return rtr;
    }
}
exports.RouteTransferRequest = RouteTransferRequest;
//# sourceMappingURL=request.js.map